@@ -21,7 +21,7 @@ use Math::BigInt;
 use Math::Random;
 use Fcntl 'SEEK_CUR';
 
-our $VERSION = '1.1';
+our $VERSION = '1.2';
 
 use overload  '+'        =>    '_join',
               '""'       =>    '_str',
@@ -46,8 +46,8 @@ sub _readblock {
     my $bitstring = '';
     while ( $i < $blocksize / 8 ) {
         $i++;
-        sysread($bitvector->{FILEIN}, my $byte, 1);
-        unless ($byte) {
+        my $num_bytes_read = sysread($bitvector->{FILEIN}, my $byte, 1);
+        unless ($num_bytes_read) {
             if (length($bitstring) < $blocksize) { 
                 $bitvector->{more_to_read} = 0;
                 $more_to_read = 0;
@@ -62,8 +62,8 @@ sub _readblock {
     my $file_pos = tell $bitvector->{FILEIN};
     # peek at the next byte; moves file position only if a
     # byte is read
-    sysread($bitvector->{FILEIN}, my $next_byte, 1);
-    if ($next_byte) {
+    my $num_bytes_read = sysread($bitvector->{FILEIN}, my $next_byte, 1);
+    if ($num_bytes_read) {
         # pretend we never read the byte
         sysseek $bitvector->{FILEIN}, $file_pos - 1, SEEK_CUR;
     } else {
@@ -200,8 +200,10 @@ sub set_bit {
     }
 }
 
-## Get the bit from the designated position. This method can also return
-## a slice of the bitvector as an instance of Algorithm::BitVector
+## Get the bit from the designated position. This method can also return a slice of a
+## bitvector.  However, note that the slice is returned as a list of the bits in the
+## index range you specified. You can easily convert the list of bits returned into a
+## bitvector in your own code.
 sub get_bit {
     my $self = shift;
     my $pos = shift;
@@ -1180,6 +1182,10 @@ bit arrays and for logical and arithmetic operations on such arrays.
 
 =head1 CHANGES
 
+Version 1.2 fixes an important bug in creating bitvectors from the contents of a disk
+file.  This version also includes corrections for some of the documentation errors
+discovered.
+
 Version 1.1 incorporates additional type checking on the operands for the overloaded
 operators.  Also fixed some minor documentation formatting issues.
 
@@ -1974,6 +1980,20 @@ position of the bit you want to set and the second for the value of the bit.
 
 =back
 
+=head3 set_value()
+
+=over 4
+
+This method can be used to change the bit pattern associated with a previously
+constructed bitvector:
+
+    $bv = Algorithm::BitVector->new( intVal => 7, size => 16 );
+    print $bv;                                 # 0000000000000111                                  
+    $bv->set_value( intVal => 45 );
+    print $bv;                                 # 101101    
+
+=back
+
 =head3 shift_left()
 
 =over 4
@@ -2004,20 +2024,6 @@ If you want to shift a bit non-circularly to the right, this is the method to ca
 
 =back
 
-=head3 set_value()
-
-=over 4
-
-This method can be used to change the bit pattern associated with a previously
-constructed bitvector:
-
-    $bv = Algorithm::BitVector->new( intVal => 7, size => 16 );
-    print $bv;                                 # 0000000000000111                                  
-    $bv->set_value( intVal => 45 );
-    print $bv;                                 # 101101    
-
-=back
-
 =head3 test_for_primality()
 
 =over 4
@@ -2104,10 +2110,10 @@ the string 'BitVector' in the subject line.
 Download the archive from CPAN in any directory of your choice.  Unpack the archive
 with a command that on a Linux machine would look like:
 
-    tar zxvf Algorithm-BitVector-1.1.tar.gz
+    tar zxvf Algorithm-BitVector-1.2.tar.gz
 
 This will create an installation directory for you whose name will be
-C<Algorithm-BitVector-1.1>.  Enter this directory and execute the following commands
+C<Algorithm-BitVector-1.2>.  Enter this directory and execute the following commands
 for a standard install of the module if you have root privileges:
 
     perl Makefile.PL
